pytilities.overloading.overload — Pytilities 1.2.0 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Pytilities 1.2.0 documentation »
- API documentation »
- pytilities »
- pytilities.overloading »

# pytilities.overloading.overload

class `pytilities.overloading.overload.` `Overload`(operation, *params)

  A list of parameters that when matched, call an associated operation.

  You can think of it as part of an operation signature

  Methods:

  > - process_call: Call overload’s operation if args match.
  > - insert_params: Insert parameters

  `insert_params`(index, *params)

    Insert parameters into the current list of parameters at index

    Parameters:

    > index :: number
    >   index of where to insert
    > params :: (Parameter...)
    >   the parameters to insert

  `process_args`(kwargs, *args)

    Process args and kwargs

    Returns: | (processed args, operation) if matched, None otherwise
    Return type: | ({string: object, callable}
    Parameters: | args ((object, ...)) – positional arguments kwargs ({string: object}) – keyword arguments

### Navigation

- index
- modules |
- next |
- previous |
- Pytilities 1.2.0 documentation »
- API documentation »
- pytilities »
- pytilities.overloading »